@@ -1,56 +1,58 @@
+import json
 import logging
 import select
 import socket
 import ssl
 import threading
 from io import BufferedReader, BufferedWriter
-from typing import Callable, Optional, Union
+from typing import Callable, Dict, Optional, Tuple, Union
 
 import lz4.block
 
-from sqlitecloud.resultset import SQCloudResult, SqliteCloudResultSet
+from sqlitecloud.resultset import SQLiteCloudResult, SQLiteCloudResultSet
 from sqlitecloud.types import (
-    SQCLOUD_CMD,
-    SQCLOUD_DEFAULT,
-    SQCLOUD_INTERNAL_ERRCODE,
-    SQCLOUD_RESULT_TYPE,
-    SQCLOUD_ROWSET,
-    SQCloudConfig,
-    SQCloudConnect,
-    SQCloudException,
-    SQCloudNumber,
-    SQCloudRowsetSignature,
-    SQCloudValue,
+    SQLITECLOUD_CMD,
+    SQLITECLOUD_DEFAULT,
+    SQLITECLOUD_INTERNAL_ERRCODE,
+    SQLITECLOUD_RESULT_TYPE,
+    SQLITECLOUD_ROWSET,
+    SQLiteCloudConfig,
+    SQLiteCloudConnect,
+    SQLiteCloudDataTypes,
+    SQLiteCloudException,
+    SQLiteCloudNumber,
+    SQLiteCloudRowsetSignature,
+    SQLiteCloudValue,
 )
 
 
 class Driver:
-    SQCLOUD_DEFAULT_UPLOAD_SIZE = 512 * 1024
+    SQLiteCloud_DEFAULT_UPLOAD_SIZE = 512 * 1024
 
     def __init__(self) -> None:
         # Used while parsing chunked rowset
-        self._rowset: SQCloudResult = None
+        self._rowset: SQLiteCloudResult = None
 
     def connect(
-        self, hostname: str, port: int, config: SQCloudConfig
-    ) -> SQCloudConnect:
+        self, hostname: str, port: int, config: SQLiteCloudConfig
+    ) -> SQLiteCloudConnect:
         """
         Connect to the SQLite Cloud server.
 
         Args:
             hostname (str): The hostname of the server.
             port (int): The port number of the server.
-            config (SQCloudConfig): The configuration for the connection.
+            config (SQLiteCloudConfig): The configuration for the connection.
 
         Returns:
-            SQCloudConnect: The connection object.
+            SQLiteCloudConnect: The connection object.
 
         Raises:
-            SQCloudException: If an error occurs while connecting the socket.
+            SQLiteCloudException: If an error occurs while connecting the socket.
         """
         sock = self._internal_connect(hostname, port, config)
 
-        connection = SQCloudConnect()
+        connection = SQLiteCloudConnect()
         connection.config = config
         connection.socket = sock
 
@@ -58,7 +60,9 @@ class Driver:
 
         return connection
 
-    def disconnect(self, conn: SQCloudConnect, only_main_socket: bool = False) -> None:
+    def disconnect(
+        self, conn: SQLiteCloudConnect, only_main_socket: bool = False
+    ) -> None:
         """
         Disconnect from the SQLite Cloud server.
         """
@@ -72,13 +76,15 @@ class Driver:
             if not only_main_socket:
                 conn.pubsub_socket = None
 
-    def execute(self, command: str, connection: SQCloudConnect) -> SQCloudResult:
+    def execute(
+        self, command: str, connection: SQLiteCloudConnect
+    ) -> SQLiteCloudResult:
         """
         Execute a query on the SQLite Cloud server.
         """
         return self._internal_run_command(connection, command)
 
-    def send_blob(self, blob: bytes, conn: SQCloudConnect) -> SQCloudResult:
+    def send_blob(self, blob: bytes, conn: SQLiteCloudConnect) -> SQLiteCloudResult:
         """
         Send a blob to the SQLite Cloud server.
         """
@@ -88,8 +94,27 @@ class Driver:
         finally:
             conn.isblob = False
 
+    def prepare_statement(
+        self,
+        query: str,
+        parameters: Union[
+            Tuple[SQLiteCloudDataTypes], Dict[Union[str, int], SQLiteCloudDataTypes]
+        ],
+    ) -> str:
+        # If parameters is a dictionary, replace the keys in the query with the values
+        if isinstance(parameters, dict):
+            for key, value in parameters.items():
+                query = query.replace(":" + str(key), self.escape_sql_parameter(value))
+
+        # If parameters is a tuple, replace each '?' in the query with a value from the tuple
+        elif isinstance(parameters, tuple):
+            for value in parameters:
+                query = query.replace("?", self.escape_sql_parameter(value), 1)
+
+        return query
+
     def is_connected(
-        self, connection: SQCloudConnect, main_socket: bool = True
+        self, connection: SQLiteCloudConnect, main_socket: bool = True
     ) -> bool:
         """
         Check if the connection is still open.
@@ -105,8 +130,35 @@ class Driver:
 
         return True
 
+    def escape_sql_parameter(self, param):
+        if param is None or param is None:
+            return "NULL"
+
+        if isinstance(param, bool):
+            return "1" if param else "0"
+
+        if isinstance(param, str):
+            # replace single quote with two single quotes
+            param = param.replace("'", "''")
+            return f"'{param}'"
+
+        if isinstance(param, (int, float)):
+            return str(param)
+
+        # serialize buffer as X'...' hex encoded string
+        if isinstance(param, bytes):
+            return f"X'{param.hex()}'"
+
+        if isinstance(param, dict) or isinstance(param, list):
+            # serialize json then escape single quotes
+            json_string = json.dumps(param)
+            json_string = json_string.replace("'", "''")
+            return f"'{json_string}'"
+
+        raise SQLiteCloudException(f"Unsupported parameter type: {type(param)}")
+
     def _internal_connect(
-        self, hostname: str, port: int, config: SQCloudConfig
+        self, hostname: str, port: int, config: SQLiteCloudConfig
     ) -> socket:
         """
         Create a socket connection to the SQLite Cloud server.
@@ -132,14 +184,16 @@ class Driver:
             sock.connect((hostname, port))
         except Exception as e:
             errmsg = "An error occurred while initializing the socket."
-            raise SQCloudException(errmsg) from e
+            raise SQLiteCloudException(errmsg) from e
 
         return sock
 
     def _internal_reconnect(self, buffer: bytes) -> bool:
         return True
 
-    def _internal_setup_pubsub(self, connection: SQCloudConnect, buffer: bytes) -> bool:
+    def _internal_setup_pubsub(
+        self, connection: SQLiteCloudConnect, buffer: bytes
+    ) -> bool:
         """
         Prepare the connection for PubSub.
         Opens a new specific socket and starts the thread to listen for incoming messages.
@@ -148,7 +202,7 @@ class Driver:
             return True
 
         if connection.pubsub_callback is None:
-            raise SQCloudException(
+            raise SQLiteCloudException(
                 "A callback function must be provided to setup the PubSub connection."
             )
 
@@ -169,7 +223,7 @@ class Driver:
 
         return True
 
-    def _internal_pubsub_thread(self, connection: SQCloudConnect) -> None:
+    def _internal_pubsub_thread(self, connection: SQLiteCloudConnect) -> None:
         blen = 2048
         buffer: bytes = b""
 
@@ -199,7 +253,7 @@ class Driver:
                         break
                 except Exception as e:
                     logging.error(
-                        f"An error occurred while reading data: {SQCLOUD_INTERNAL_ERRCODE.NETWORK.value} ({e})."
+                        f"An error occurred while reading data: {SQLITECLOUD_INTERNAL_ERRCODE.NETWORK.value} ({e})."
                     )
                     break
 
@@ -208,24 +262,24 @@ class Driver:
                 blen -= nread
                 buffer += data
 
-                sqcloud_number = self._internal_parse_number(buffer)
-                clen = sqcloud_number.value
+                SQLiteCloud_number = self._internal_parse_number(buffer)
+                clen = SQLiteCloud_number.value
                 if clen == 0:
                     continue
 
                 # check if read is complete
                 # clen is the lenght parsed in the buffer
                 # cstart is the index of the first space
-                cstart = sqcloud_number.cstart
+                cstart = SQLiteCloud_number.cstart
                 if clen + cstart != tread:
                     continue
 
                 result = self._internal_parse_buffer(connection, buffer, tread)
-                if result.tag == SQCLOUD_RESULT_TYPE.RESULT_STRING:
-                    result.tag = SQCLOUD_RESULT_TYPE.RESULT_JSON
+                if result.tag == SQLITECLOUD_RESULT_TYPE.RESULT_STRING:
+                    result.tag = SQLITECLOUD_RESULT_TYPE.RESULT_JSON
 
                 connection.pubsub_callback(
-                    connection, SqliteCloudResultSet(result), connection.pubsub_data
+                    connection, SQLiteCloudResultSet(result), connection.pubsub_data
                 )
         except Exception as e:
             logging.error(f"An error occurred while parsing data: {e}.")
@@ -235,7 +289,7 @@ class Driver:
 
     def upload_database(
         self,
-        connection: SQCloudConnect,
+        connection: SQLiteCloudConnect,
         dbname: str,
         key: Optional[str],
         is_file_transfer: bool,
@@ -249,7 +303,7 @@ class Driver:
         Uploads a database to the server.
 
         Args:
-            connection (SQCloudConnect): The connection object to the SQLite Cloud server.
+            connection (SQLiteCloudConnect): The connection object to the SQLite Cloud server.
             dbname (str): The name of the database to upload.
             key (Optional[str]): The encryption key for the database, if applicable.
             is_file_transfer (bool): Indicates whether the database is being transferred as a file.
@@ -260,7 +314,7 @@ class Driver:
             xCallback (Callable[[BufferedReader, int, int, int], bytes]): The callback function to read the buffer.
 
         Raises:
-            SQCloudException: If an error occurs during the upload process.
+            SQLiteCloudException: If an error occurs during the upload process.
 
         """
         keyarg = "KEY " if key else ""
@@ -277,7 +331,7 @@ class Driver:
         # execute command on server side
         result = self._internal_run_command(connection, command)
         if not result.data[0]:
-            raise SQCloudException(
+            raise SQLiteCloudException(
                 "An error occurred while initializing the upload of the database."
             )
 
@@ -287,12 +341,12 @@ class Driver:
         try:
             while True:
                 # execute callback to read buffer
-                blen = SQCLOUD_DEFAULT.UPLOAD_SIZE.value
+                blen = SQLITECLOUD_DEFAULT.UPLOAD_SIZE.value
                 try:
                     buffer = xCallback(fd, blen, dbsize, nprogress)
                     blen = len(buffer)
                 except Exception as e:
-                    raise SQCloudException(
+                    raise SQLiteCloudException(
                         "An error occurred while reading the file."
                     ) from e
 
@@ -300,7 +354,7 @@ class Driver:
                     # send also the final confirmation blob of zero bytes
                     self.send_blob(buffer, connection)
                 except Exception as e:
-                    raise SQCloudException(
+                    raise SQLiteCloudException(
                         "An error occurred while uploading the file."
                     ) from e
 
@@ -316,7 +370,7 @@ class Driver:
 
     def download_database(
         self,
-        connection: SQCloudConnect,
+        connection: SQLiteCloudConnect,
         dbname: str,
         fd: BufferedWriter,
         xCallback: Callable[[BufferedWriter, int, int, int], bytes],
@@ -326,14 +380,14 @@ class Driver:
         Downloads a database from the SQLite Cloud service.
 
         Args:
-            connection (SQCloudConnect): The connection object used to communicate with the SQLite Cloud service.
+            connection (SQLiteCloudConnect): The connection object used to communicate with the SQLite Cloud service.
             dbname (str): The name of the database to download.
             fd (BufferedWriter): The file descriptor to write the downloaded data to.
             xCallback (Callable[[BufferedWriter, int, int, int], bytes]): A callback function to write downloaded data with the download progress information.
             if_exists (bool): If True, the download won't rise an exception if database is missing.
 
         Raises:
-            SQCloudException: If an error occurs while downloading the database.
+            SQLiteCloudException: If an error occurs while downloading the database.
 
         """
         exists_cmd = " IF EXISTS" if if_exists else ""
@@ -342,7 +396,7 @@ class Driver:
         )
 
         if result.nrows == 0:
-            raise SQCloudException(
+            raise SQLiteCloudException(
                 "An error occurred while initializing the download of the database."
             )
 
@@ -373,13 +427,17 @@ class Driver:
             raise e
 
     def _internal_config_apply(
-        self, connection: SQCloudConnect, config: SQCloudConfig
+        self, connection: SQLiteCloudConnect, config: SQLiteCloudConfig
     ) -> None:
         if config.timeout > 0:
             connection.socket.settimeout(config.timeout)
 
         buffer = ""
 
+        # it must be executed before authentication command
+        if config.non_linearizable:
+            buffer += "SET CLIENT KEY NONLINEARIZABLE TO 1;"
+
         if config.account.apikey:
             buffer += f"AUTH APIKEY {config.account.apikey};"
 
@@ -398,9 +456,6 @@ class Driver:
         if config.zerotext:
             buffer += "SET CLIENT KEY ZEROTEXT TO 1;"
 
-        if config.non_linearizable:
-            buffer += "SET CLIENT KEY NONLINEARIZABLE TO 1;"
-
         if config.noblob:
             buffer += "SET CLIENT KEY NOBLOB TO 1;"
 
@@ -418,16 +473,22 @@ class Driver:
 
     def _internal_run_command(
         self,
-        connection: SQCloudConnect,
+        connection: SQLiteCloudConnect,
         command: Union[str, bytes],
         main_socket: bool = True,
-    ) -> SQCloudResult:
+    ) -> SQLiteCloudResult:
+        if not self.is_connected(connection, main_socket):
+            raise SQLiteCloudException(
+                "The connection is closed.",
+                SQLITECLOUD_INTERNAL_ERRCODE.NETWORK,
+            )
+
         self._internal_socket_write(connection, command, main_socket)
         return self._internal_socket_read(connection, main_socket)
 
     def _internal_socket_write(
         self,
-        connection: SQCloudConnect,
+        connection: SQLiteCloudConnect,
         command: Union[str, bytes],
         main_socket: bool = True,
     ) -> None:
@@ -443,9 +504,9 @@ class Driver:
         try:
             sock.sendall(header.encode())
         except Exception as exc:
-            raise SQCloudException(
+            raise SQLiteCloudException(
                 "An error occurred while writing header data.",
-                SQCLOUD_INTERNAL_ERRCODE.NETWORK,
+                SQLITECLOUD_INTERNAL_ERRCODE.NETWORK,
             ) from exc
 
         # write buffer
@@ -454,14 +515,14 @@ class Driver:
         try:
             sock.sendall(buffer)
         except Exception as exc:
-            raise SQCloudException(
+            raise SQLiteCloudException(
                 "An error occurred while writing data.",
-                SQCLOUD_INTERNAL_ERRCODE.NETWORK,
+                SQLITECLOUD_INTERNAL_ERRCODE.NETWORK,
             ) from exc
 
     def _internal_socket_read(
-        self, connection: SQCloudConnect, main_socket: bool = True
-    ) -> SQCloudResult:
+        self, connection: SQLiteCloudConnect, main_socket: bool = True
+    ) -> SQLiteCloudResult:
         """
         Read from the socket and parse the response.
 
@@ -480,11 +541,11 @@ class Driver:
             try:
                 data = sock.recv(buffer_size)
                 if not data:
-                    raise SQCloudException("Incomplete response from server.")
+                    raise SQLiteCloudException("Incomplete response from server.")
             except Exception as exc:
-                raise SQCloudException(
+                raise SQLiteCloudException(
                     "An error occurred while reading data from the socket.",
-                    SQCLOUD_INTERNAL_ERRCODE.NETWORK,
+                    SQLITECLOUD_INTERNAL_ERRCODE.NETWORK,
                 ) from exc
 
             # the expected data length to read
@@ -496,23 +557,23 @@ class Driver:
             c = chr(buffer[0])
 
             if (
-                c == SQCLOUD_CMD.INT.value
-                or c == SQCLOUD_CMD.FLOAT.value
-                or c == SQCLOUD_CMD.NULL.value
+                c == SQLITECLOUD_CMD.INT.value
+                or c == SQLITECLOUD_CMD.FLOAT.value
+                or c == SQLITECLOUD_CMD.NULL.value
             ):
                 if not buffer.endswith(b" "):
                     continue
-            elif c == SQCLOUD_CMD.ROWSET_CHUNK.value:
-                isEndOfChunk = buffer.endswith(SQCLOUD_ROWSET.CHUNKS_END.value)
+            elif c == SQLITECLOUD_CMD.ROWSET_CHUNK.value:
+                isEndOfChunk = buffer.endswith(SQLITECLOUD_ROWSET.CHUNKS_END.value)
                 if not isEndOfChunk:
                     continue
             else:
-                sqcloud_number = self._internal_parse_number(buffer)
-                n = sqcloud_number.value
-                cstart = sqcloud_number.cstart
+                SQLiteCloud_number = self._internal_parse_number(buffer)
+                n = SQLiteCloud_number.value
+                cstart = SQLiteCloud_number.cstart
 
                 can_be_zerolength = (
-                    c == SQCLOUD_CMD.BLOB.value or c == SQCLOUD_CMD.STRING.value
+                    c == SQLITECLOUD_CMD.BLOB.value or c == SQLITECLOUD_CMD.STRING.value
                 )
                 if n == 0 and not can_be_zerolength:
                     continue
@@ -521,9 +582,11 @@ class Driver:
 
             return self._internal_parse_buffer(connection, buffer, len(buffer))
 
-    def _internal_parse_number(self, buffer: bytes, index: int = 1) -> SQCloudNumber:
-        sqcloud_number = SQCloudNumber()
-        sqcloud_number.value = 0
+    def _internal_parse_number(
+        self, buffer: bytes, index: int = 1
+    ) -> SQLiteCloudNumber:
+        SQLiteCloud_number = SQLiteCloudNumber()
+        SQLiteCloud_number.value = 0
         extvalue = 0
         isext = False
         blen = len(buffer)
@@ -539,9 +602,9 @@ class Driver:
 
             # check for end of value
             if c == " ":
-                sqcloud_number.cstart = i + 1
-                sqcloud_number.extcode = extvalue
-                return sqcloud_number
+                SQLiteCloud_number.cstart = i + 1
+                SQLiteCloud_number.extcode = extvalue
+                return SQLiteCloud_number
 
             val = int(c) if c.isdigit() else 0
 
@@ -549,14 +612,14 @@ class Driver:
             if isext:
                 extvalue = (extvalue * 10) + val
             else:
-                sqcloud_number.value = (sqcloud_number.value * 10) + val
+                SQLiteCloud_number.value = (SQLiteCloud_number.value * 10) + val
 
-        sqcloud_number.value = 0
-        return sqcloud_number
+        SQLiteCloud_number.value = 0
+        return SQLiteCloud_number
 
     def _internal_parse_buffer(
-        self, connection: SQCloudConnect, buffer: bytes, blen: int
-    ) -> SQCloudResult:
+        self, connection: SQLiteCloudConnect, buffer: bytes, blen: int
+    ) -> SQLiteCloudResult:
         # possible return values:
         # True 	=> OK
         # False 	=> error
@@ -569,15 +632,15 @@ class Driver:
 
         # check OK value
         if buffer == b"+2 OK":
-            return SQCloudResult(SQCLOUD_RESULT_TYPE.RESULT_OK, True)
+            return SQLiteCloudResult(SQLITECLOUD_RESULT_TYPE.RESULT_OK, True)
 
         cmd = chr(buffer[0])
 
         # check for compressed result
-        if cmd == SQCLOUD_CMD.COMPRESSED.value:
+        if cmd == SQLITECLOUD_CMD.COMPRESSED.value:
             buffer = self._internal_uncompress_data(buffer)
             if buffer is None:
-                raise SQCloudException(
+                raise SQLiteCloudException(
                     f"An error occurred while decompressing the input buffer of len {blen}."
                 )
 
@@ -587,53 +650,54 @@ class Driver:
 
         # first character contains command type
         if cmd in [
-            SQCLOUD_CMD.ZEROSTRING.value,
-            SQCLOUD_CMD.RECONNECT.value,
-            SQCLOUD_CMD.PUBSUB.value,
-            SQCLOUD_CMD.COMMAND.value,
-            SQCLOUD_CMD.STRING.value,
-            SQCLOUD_CMD.ARRAY.value,
-            SQCLOUD_CMD.BLOB.value,
-            SQCLOUD_CMD.JSON.value,
+            SQLITECLOUD_CMD.ZEROSTRING.value,
+            SQLITECLOUD_CMD.RECONNECT.value,
+            SQLITECLOUD_CMD.PUBSUB.value,
+            SQLITECLOUD_CMD.COMMAND.value,
+            SQLITECLOUD_CMD.STRING.value,
+            SQLITECLOUD_CMD.ARRAY.value,
+            SQLITECLOUD_CMD.BLOB.value,
+            SQLITECLOUD_CMD.JSON.value,
         ]:
             sqlite_number = self._internal_parse_number(buffer)
             len_ = sqlite_number.value
             cstart = sqlite_number.cstart
             if len_ == 0:
-                return SQCloudResult(SQCLOUD_RESULT_TYPE.RESULT_STRING, "")
+                return SQLiteCloudResult(SQLITECLOUD_RESULT_TYPE.RESULT_STRING, "")
 
             tag = (
-                SQCLOUD_RESULT_TYPE.RESULT_JSON
-                if cmd == SQCLOUD_CMD.JSON.value
-                else SQCLOUD_RESULT_TYPE.RESULT_STRING
+                SQLITECLOUD_RESULT_TYPE.RESULT_JSON
+                if cmd == SQLITECLOUD_CMD.JSON.value
+                else SQLITECLOUD_RESULT_TYPE.RESULT_STRING
             )
 
-            if cmd == SQCLOUD_CMD.ZEROSTRING.value:
+            if cmd == SQLITECLOUD_CMD.ZEROSTRING.value:
                 len_ -= 1
             clone = buffer[cstart : cstart + len_]
 
-            if cmd == SQCLOUD_CMD.COMMAND.value:
+            if cmd == SQLITECLOUD_CMD.COMMAND.value:
                 return self._internal_run_command(connection, clone)
-            elif cmd == SQCLOUD_CMD.PUBSUB.value:
-                return SQCloudResult(
-                    SQCLOUD_RESULT_TYPE.RESULT_OK,
+            elif cmd == SQLITECLOUD_CMD.PUBSUB.value:
+                return SQLiteCloudResult(
+                    SQLITECLOUD_RESULT_TYPE.RESULT_OK,
                     self._internal_setup_pubsub(connection, clone),
                 )
-            elif cmd == SQCLOUD_CMD.RECONNECT.value:
-                return SQCloudResult(
-                    SQCLOUD_RESULT_TYPE.RESULT_OK, self._internal_reconnect(clone)
+            elif cmd == SQLITECLOUD_CMD.RECONNECT.value:
+                return SQLiteCloudResult(
+                    SQLITECLOUD_RESULT_TYPE.RESULT_OK, self._internal_reconnect(clone)
                 )
-            elif cmd == SQCLOUD_CMD.ARRAY.value:
-                return SQCloudResult(
-                    SQCLOUD_RESULT_TYPE.RESULT_ARRAY, self._internal_parse_array(clone)
+            elif cmd == SQLITECLOUD_CMD.ARRAY.value:
+                return SQLiteCloudResult(
+                    SQLITECLOUD_RESULT_TYPE.RESULT_ARRAY,
+                    self._internal_parse_array(clone),
                 )
-            elif cmd == SQCLOUD_CMD.BLOB.value:
-                tag = SQCLOUD_RESULT_TYPE.RESULT_BLOB
+            elif cmd == SQLITECLOUD_CMD.BLOB.value:
+                tag = SQLITECLOUD_RESULT_TYPE.RESULT_BLOB
 
-            clone = clone.decode() if cmd != SQCLOUD_CMD.BLOB.value else clone
-            return SQCloudResult(tag, clone)
+            clone = clone.decode() if cmd != SQLITECLOUD_CMD.BLOB.value else clone
+            return SQLiteCloudResult(tag, clone)
 
-        elif cmd == SQCLOUD_CMD.ERROR.value:
+        elif cmd == SQLITECLOUD_CMD.ERROR.value:
             # -LEN ERRCODE:EXTCODE ERRMSG
             sqlite_number = self._internal_parse_number(buffer)
             len_ = sqlite_number.value
@@ -649,9 +713,9 @@ class Driver:
             len_ -= cstart2
             errmsg = clone[cstart2:]
 
-            raise SQCloudException(errmsg.decode(), errcode, xerrcode)
+            raise SQLiteCloudException(errmsg.decode(), errcode, xerrcode)
 
-        elif cmd in [SQCLOUD_CMD.ROWSET.value, SQCLOUD_CMD.ROWSET_CHUNK.value]:
+        elif cmd in [SQLITECLOUD_CMD.ROWSET.value, SQLITECLOUD_CMD.ROWSET_CHUNK.value]:
             # CMD_ROWSET:          *LEN 0:VERSION ROWS COLS DATA
             # - When decompressed, LEN for ROWSET is *0
             #
@@ -659,7 +723,7 @@ class Driver:
             #
             rowset_signature = self._internal_parse_rowset_signature(buffer)
             if rowset_signature.start < 0:
-                raise SQCloudException("Cannot parse rowset signature")
+                raise SQLiteCloudException("Cannot parse rowset signature")
 
             # check for end-of-chunk condition
             if rowset_signature.start == 0 and rowset_signature.version == 0:
@@ -679,35 +743,35 @@ class Driver:
             # continue parsing next chunk in the buffer
             sign_len = rowset_signature.len
             buffer = buffer[sign_len + len(f"/{sign_len} ") :]
-            if cmd == SQCLOUD_CMD.ROWSET_CHUNK.value and buffer:
+            if cmd == SQLITECLOUD_CMD.ROWSET_CHUNK.value and buffer:
                 return self._internal_parse_buffer(connection, buffer, len(buffer))
 
             return rowset
 
-        elif cmd == SQCLOUD_CMD.NULL.value:
-            return SQCloudResult(SQCLOUD_RESULT_TYPE.RESULT_NONE, None)
+        elif cmd == SQLITECLOUD_CMD.NULL.value:
+            return SQLiteCloudResult(SQLITECLOUD_RESULT_TYPE.RESULT_NONE, None)
 
-        elif cmd in [SQCLOUD_CMD.INT.value, SQCLOUD_CMD.FLOAT.value]:
-            sqcloud_value = self._internal_parse_value(buffer)
-            clone = sqcloud_value.value
+        elif cmd in [SQLITECLOUD_CMD.INT.value, SQLITECLOUD_CMD.FLOAT.value]:
+            SQLiteCloud_value = self._internal_parse_value(buffer)
+            clone = SQLiteCloud_value.value
 
             tag = (
-                SQCLOUD_RESULT_TYPE.RESULT_INTEGER
-                if cmd == SQCLOUD_CMD.INT.value
-                else SQCLOUD_RESULT_TYPE.RESULT_FLOAT
+                SQLITECLOUD_RESULT_TYPE.RESULT_INTEGER
+                if cmd == SQLITECLOUD_CMD.INT.value
+                else SQLITECLOUD_RESULT_TYPE.RESULT_FLOAT
             )
 
             if clone is None:
-                return SQCloudResult(tag, 0)
+                return SQLiteCloudResult(tag, 0)
 
-            if cmd == SQCLOUD_CMD.INT.value:
-                return SQCloudResult(tag, int(clone))
-            return SQCloudResult(tag, float(clone))
+            if cmd == SQLITECLOUD_CMD.INT.value:
+                return SQLiteCloudResult(tag, int(clone))
+            return SQLiteCloudResult(tag, float(clone))
 
-        elif cmd == SQCLOUD_CMD.RAWJSON.value:
-            return SQCloudResult(SQCLOUD_RESULT_TYPE.RESULT_NONE, None)
+        elif cmd == SQLITECLOUD_CMD.RAWJSON.value:
+            return SQLiteCloudResult(SQLITECLOUD_RESULT_TYPE.RESULT_NONE, None)
 
-        return SQCloudResult(SQCLOUD_RESULT_TYPE.RESULT_NONE, None)
+        return SQLiteCloudResult(SQLITECLOUD_RESULT_TYPE.RESULT_NONE, None)
 
     def _internal_uncompress_data(self, buffer: bytes) -> Optional[bytes]:
         """
@@ -757,62 +821,64 @@ class Driver:
 
         r: str = []
         for i in range(n):
-            sqcloud_value = self._internal_parse_value(buffer, start)
-            start += sqcloud_value.cellsize
-            r.append(sqcloud_value.value)
+            SQLiteCloud_value = self._internal_parse_value(buffer, start)
+            start += SQLiteCloud_value.cellsize
+            r.append(SQLiteCloud_value.value)
 
         return r
 
-    def _internal_parse_value(self, buffer: bytes, index: int = 0) -> SQCloudValue:
-        sqcloud_value = SQCloudValue()
+    def _internal_parse_value(self, buffer: bytes, index: int = 0) -> SQLiteCloudValue:
+        SQLiteCloud_value = SQLiteCloudValue()
         len = 0
         cellsize = 0
 
         # handle special NULL value case
         c = chr(buffer[index])
-        if buffer is None or c == SQCLOUD_CMD.NULL.value:
+        if buffer is None or c == SQLITECLOUD_CMD.NULL.value:
             len = 0
             if cellsize is not None:
                 cellsize = 2
 
-            sqcloud_value.len = len
-            sqcloud_value.cellsize = cellsize
+            SQLiteCloud_value.len = len
+            SQLiteCloud_value.cellsize = cellsize
 
-            return sqcloud_value
+            return SQLiteCloud_value
 
-        sqcloud_number = self._internal_parse_number(buffer, index + 1)
-        blen = sqcloud_number.value
-        cstart = sqcloud_number.cstart
+        SQLiteCloud_number = self._internal_parse_number(buffer, index + 1)
+        blen = SQLiteCloud_number.value
+        cstart = SQLiteCloud_number.cstart
 
         # handle decimal/float cases
-        if c == SQCLOUD_CMD.INT.value or c == SQCLOUD_CMD.FLOAT.value:
+        if c == SQLITECLOUD_CMD.INT.value or c == SQLITECLOUD_CMD.FLOAT.value:
             nlen = cstart - index
             len = nlen - 2
             cellsize = nlen
 
-            sqcloud_value.value = (buffer[index + 1 : index + 1 + len]).decode()
-            sqcloud_value.len
-            sqcloud_value.cellsize = cellsize
+            SQLiteCloud_value.value = (buffer[index + 1 : index + 1 + len]).decode()
+            SQLiteCloud_value.len
+            SQLiteCloud_value.cellsize = cellsize
 
-            return sqcloud_value
+            return SQLiteCloud_value
 
-        len = blen - 1 if c == SQCLOUD_CMD.ZEROSTRING.value else blen
+        len = blen - 1 if c == SQLITECLOUD_CMD.ZEROSTRING.value else blen
         cellsize = blen + cstart - index
 
-        sqcloud_value.value = (buffer[cstart : cstart + len]).decode()
-        sqcloud_value.len = len
-        sqcloud_value.cellsize = cellsize
+        SQLiteCloud_value.value = (buffer[cstart : cstart + len]).decode()
+        SQLiteCloud_value.len = len
+        SQLiteCloud_value.cellsize = cellsize
 
-        return sqcloud_value
+        return SQLiteCloud_value
 
-    def _internal_parse_rowset_signature(self, buffer: bytes) -> SQCloudRowsetSignature:
+    def _internal_parse_rowset_signature(
+        self, buffer: bytes
+    ) -> SQLiteCloudRowsetSignature:
         # ROWSET:          *LEN 0:VERS NROWS NCOLS DATA
         # ROWSET in CHUNK: /LEN IDX:VERS NROWS NCOLS DATA
 
-        signature = SQCloudRowsetSignature()
+        signature = SQLiteCloudRowsetSignature()
 
         # check for end-of-chunk condition
-        if buffer == SQCLOUD_ROWSET.CHUNKS_END.value:
+        if buffer == SQLITECLOUD_ROWSET.CHUNKS_END.value:
             signature.version = 0
             signature.start = 0
             return signature
@@ -844,21 +910,21 @@ class Driver:
 
                 return signature
             else:
-                return SQCloudRowsetSignature()
-        return SQCloudRowsetSignature()
+                return SQLiteCloudRowsetSignature()
+        return SQLiteCloudRowsetSignature()
 
     def _internal_parse_rowset(
         self, buffer: bytes, start: int, idx: int, version: int, nrows: int, ncols: int
-    ) -> SQCloudResult:
+    ) -> SQLiteCloudResult:
         rowset = None
         n = start
-        ischunk = chr(buffer[0]) == SQCLOUD_CMD.ROWSET_CHUNK.value
+        ischunk = chr(buffer[0]) == SQLITECLOUD_CMD.ROWSET_CHUNK.value
 
         # idx == 0 means first (and only) chunk for rowset
         # idx == 1 means first chunk for chunked rowset
         first_chunk = (ischunk and idx == 1) or (not ischunk and idx == 0)
         if first_chunk:
-            rowset = SQCloudResult(SQCLOUD_RESULT_TYPE.RESULT_ROWSET)
+            rowset = SQLiteCloudResult(SQLITECLOUD_RESULT_TYPE.RESULT_ROWSET)
             rowset.nrows = nrows
             rowset.ncols = ncols
             rowset.version = version
@@ -867,7 +933,7 @@ class Driver:
                 self._rowset = rowset
             n = self._internal_parse_rowset_header(rowset, buffer, start)
             if n <= 0:
-                raise SQCloudException("Cannot parse rowset header")
+                raise SQLiteCloudException("Cannot parse rowset header")
         else:
             rowset = self._rowset
             rowset.nrows += nrows
@@ -878,16 +944,16 @@ class Driver:
         return rowset
 
     def _internal_parse_rowset_header(
-        self, rowset: SQCloudResult, buffer: bytes, start: int
+        self, rowset: SQLiteCloudResult, buffer: bytes, start: int
     ) -> int:
         ncols = rowset.ncols
 
         # parse column names
         rowset.colname = []
         for i in range(ncols):
-            sqcloud_number = self._internal_parse_number(buffer, start)
-            number_len = sqcloud_number.value
-            cstart = sqcloud_number.cstart
+            SQLiteCloud_number = self._internal_parse_number(buffer, start)
+            number_len = SQLiteCloud_number.value
+            cstart = SQLiteCloud_number.cstart
             value = buffer[cstart : cstart + number_len]
             rowset.colname.append(value.decode())
             start = cstart + number_len
@@ -896,14 +962,16 @@ class Driver:
             return start
 
         if rowset.version != 2:
-            raise SQCloudException(f"Rowset version {rowset.version} is not supported.")
+            raise SQLiteCloudException(
+                f"Rowset version {rowset.version} is not supported."
+            )
 
         # parse declared types
         rowset.decltype = []
         for i in range(ncols):
-            sqcloud_number = self._internal_parse_number(buffer, start)
-            number_len = sqcloud_number.value
-            cstart = sqcloud_number.cstart
+            SQLiteCloud_number = self._internal_parse_number(buffer, start)
+            number_len = SQLiteCloud_number.value
+            cstart = SQLiteCloud_number.cstart
             value = buffer[cstart : cstart + number_len]
             rowset.decltype.append(value.decode())
             start = cstart + number_len
@@ -911,9 +979,9 @@ class Driver:
         # parse database names
         rowset.dbname = []
         for i in range(ncols):
-            sqcloud_number = self._internal_parse_number(buffer, start)
-            number_len = sqcloud_number.value
-            cstart = sqcloud_number.cstart
+            SQLiteCloud_number = self._internal_parse_number(buffer, start)
+            number_len = SQLiteCloud_number.value
+            cstart = SQLiteCloud_number.cstart
             value = buffer[cstart : cstart + number_len]
             rowset.dbname.append(value.decode())
             start = cstart + number_len
@@ -921,9 +989,9 @@ class Driver:
         # parse table names
         rowset.tblname = []
         for i in range(ncols):
-            sqcloud_number = self._internal_parse_number(buffer, start)
-            number_len = sqcloud_number.value
-            cstart = sqcloud_number.cstart
+            SQLiteCloud_number = self._internal_parse_number(buffer, start)
+            number_len = SQLiteCloud_number.value
+            cstart = SQLiteCloud_number.cstart
             value = buffer[cstart : cstart + number_len]
             rowset.tblname.append(value.decode())
             start = cstart + number_len
@@ -931,9 +999,9 @@ class Driver:
         # parse column original names
         rowset.origname = []
         for i in range(ncols):
-            sqcloud_number = self._internal_parse_number(buffer, start)
-            number_len = sqcloud_number.value
-            cstart = sqcloud_number.cstart
+            SQLiteCloud_number = self._internal_parse_number(buffer, start)
+            number_len = SQLiteCloud_number.value
+            cstart = SQLiteCloud_number.cstart
             value = buffer[cstart : cstart + number_len]
             rowset.origname.append(value.decode())
             start = cstart + number_len
@@ -941,31 +1009,31 @@ class Driver:
         # parse not null flags
         rowset.notnull = []
         for i in range(ncols):
-            sqcloud_number = self._internal_parse_number(buffer, start)
-            rowset.notnull.append(sqcloud_number.value)
-            start = sqcloud_number.cstart
+            SQLiteCloud_number = self._internal_parse_number(buffer, start)
+            rowset.notnull.append(SQLiteCloud_number.value)
+            start = SQLiteCloud_number.cstart
 
         # parse primary key flags
         rowset.prikey = []
         for i in range(ncols):
-            sqcloud_number = self._internal_parse_number(buffer, start)
-            rowset.prikey.append(sqcloud_number.value)
-            start = sqcloud_number.cstart
+            SQLiteCloud_number = self._internal_parse_number(buffer, start)
+            rowset.prikey.append(SQLiteCloud_number.value)
+            start = SQLiteCloud_number.cstart
 
         # parse autoincrement flags
         rowset.autoinc = []
         for i in range(ncols):
-            sqcloud_number = self._internal_parse_number(buffer, start)
-            rowset.autoinc.append(sqcloud_number.value)
-            start = sqcloud_number.cstart
+            SQLiteCloud_number = self._internal_parse_number(buffer, start)
+            rowset.autoinc.append(SQLiteCloud_number.value)
+            start = SQLiteCloud_number.cstart
 
         return start
 
     def _internal_parse_rowset_values(
-        self, rowset: SQCloudResult, buffer: bytes, start: int, bound: int
+        self, rowset: SQLiteCloudResult, buffer: bytes, start: int, bound: int
     ):
         # loop to parse each individual value
         for i in range(bound):
-            sqcloud_value = self._internal_parse_value(buffer, start)
-            start += sqcloud_value.cellsize
-            rowset.data.append(sqcloud_value.value)
+            SQLiteCloud_value = self._internal_parse_value(buffer, start)
+            start += SQLiteCloud_value.cellsize
+            rowset.data.append(SQLiteCloud_value.value)
