@@ -1,21 +1,21 @@
 from typing import Callable, Optional
 
 from sqlitecloud.driver import Driver
-from sqlitecloud.resultset import SqliteCloudResultSet
-from sqlitecloud.types import SQCLOUD_PUBSUB_SUBJECT, SQCloudConnect
+from sqlitecloud.resultset import SQLiteCloudResultSet
+from sqlitecloud.types import SQLITECLOUD_PUBSUB_SUBJECT, SQLiteCloudConnect
 
 
-class SqliteCloudPubSub:
+class SQLiteCloudPubSub:
     def __init__(self) -> None:
         self._driver = Driver()
 
     def listen(
         self,
-        connection: SQCloudConnect,
-        subject_type: SQCLOUD_PUBSUB_SUBJECT,
+        connection: SQLiteCloudConnect,
+        subject_type: SQLITECLOUD_PUBSUB_SUBJECT,
         subject_name: str,
         callback: Callable[
-            [SQCloudConnect, Optional[SqliteCloudResultSet], Optional[any]], None
+            [SQLiteCloudConnect, Optional[SQLiteCloudResultSet], Optional[any]], None
         ],
         data: Optional[any] = None,
     ) -> None:
@@ -28,8 +28,8 @@ class SqliteCloudPubSub:
 
     def unlisten(
         self,
-        connection: SQCloudConnect,
-        subject_type: SQCLOUD_PUBSUB_SUBJECT,
+        connection: SQLiteCloudConnect,
+        subject_type: SQLITECLOUD_PUBSUB_SUBJECT,
         subject_name: str,
     ) -> None:
         subject = "TABLE " if subject_type.value == "TABLE" else ""
@@ -40,17 +40,19 @@ class SqliteCloudPubSub:
         connection.pubsub_data = None
 
     def create_channel(
-        self, connection: SQCloudConnect, name: str, if_not_exists: bool = False
+        self, connection: SQLiteCloudConnect, name: str, if_not_exists: bool = False
     ) -> None:
         if if_not_exists:
             self._driver.execute(f"CREATE CHANNEL {name} IF NOT EXISTS;", connection)
         else:
             self._driver.execute(f"CREATE CHANNEL {name};", connection)
 
-    def notify_channel(self, connection: SQCloudConnect, name: str, data: str) -> None:
+    def notify_channel(
+        self, connection: SQLiteCloudConnect, name: str, data: str
+    ) -> None:
         self._driver.execute(f"NOTIFY {name} '{data}';", connection)
 
-    def set_pubsub_only(self, connection: SQCloudConnect) -> None:
+    def set_pubsub_only(self, connection: SQLiteCloudConnect) -> None:
         """
         Close the main socket, leaving only the pub/sub socket opened and ready
         to receive incoming notifications from subscripted channels and tables.
@@ -60,10 +62,10 @@ class SqliteCloudPubSub:
         self._driver.execute("PUBSUB ONLY;", connection)
         self._driver.disconnect(connection, only_main_socket=True)
 
-    def is_connected(self, connection: SQCloudConnect) -> bool:
+    def is_connected(self, connection: SQLiteCloudConnect) -> bool:
         return self._driver.is_connected(connection, False)
 
-    def list_connections(self, connection: SQCloudConnect) -> SqliteCloudResultSet:
-        return SqliteCloudResultSet(
+    def list_connections(self, connection: SQLiteCloudConnect) -> SQLiteCloudResultSet:
+        return SQLiteCloudResultSet(
             self._driver.execute("LIST PUBSUB CONNECTIONS;", connection)
         )
