@@ -1,16 +1,20 @@
 import types
 from asyncio import AbstractEventLoop
 from enum import Enum
-from typing import Callable, Optional
+from typing import Any, Callable, Dict, Optional, Union
+from urllib import parse
+
+# Basic types supported by SQLite Cloud APIs
+SQLiteCloudDataTypes = Union[str, int, bool, Dict[Union[str, int], Any], bytes, None]
 
 
-class SQCLOUD_DEFAULT(Enum):
+class SQLITECLOUD_DEFAULT(Enum):
     PORT = 8860
     TIMEOUT = 12
     UPLOAD_SIZE = 512 * 1024
 
 
-class SQCLOUD_CMD(Enum):
+class SQLITECLOUD_CMD(Enum):
     STRING = "+"
     ZEROSTRING = "!"
     ERROR = "-"
@@ -29,11 +33,19 @@ class SQCLOUD_CMD(Enum):
     ARRAY = "="
 
 
-class SQCLOUD_ROWSET(Enum):
+class SQLITECLOUD_ROWSET(Enum):
     CHUNKS_END = b"/6 0 0 0 "
 
 
-class SQCLOUD_INTERNAL_ERRCODE(Enum):
+class SQLITECLOUD_VALUE_TYPE(Enum):
+    INTEGER = "INTEGER"
+    FLOAT = "REAL"
+    TEXT = "TEXT"
+    BLOB = "BLOB"
+    NULL = "NULL"
+
+
+class SQLITECLOUD_INTERNAL_ERRCODE(Enum):
     """
     Clients error codes.
     """
@@ -42,7 +54,7 @@ class SQCLOUD_INTERNAL_ERRCODE(Enum):
     NETWORK = 100005
 
 
-class SQCLOUD_ERRCODE(Enum):
+class SQLITECLOUD_ERRCODE(Enum):
     """
     Error codes from Sqlite Cloud.
     """
@@ -56,7 +68,7 @@ class SQCLOUD_ERRCODE(Enum):
     RAFT = 10006
 
 
-class SQCLOUD_RESULT_TYPE(Enum):
+class SQLITECLOUD_RESULT_TYPE(Enum):
     RESULT_OK = 0
     RESULT_ERROR = 1
     RESULT_STRING = 2
@@ -69,7 +81,7 @@ class SQCLOUD_RESULT_TYPE(Enum):
     RESULT_BLOB = 9
 
 
-class SQCLOUD_PUBSUB_SUBJECT(Enum):
+class SQLITECLOUD_PUBSUB_SUBJECT(Enum):
     """
     Subjects that can be subscribed to by PubSub.
     """
@@ -78,7 +90,7 @@ class SQCLOUD_PUBSUB_SUBJECT(Enum):
     CHANNEL = "CHANNEL"
 
 
-class SQCloudRowsetSignature:
+class SQLiteCloudRowsetSignature:
     """
     Represents the parsed signature for a rowset.
     """
@@ -92,14 +104,14 @@ class SQCloudRowsetSignature:
         self.ncols: int = 0
 
 
-class SqliteCloudAccount:
+class SQLiteCloudAccount:
     def __init__(
         self,
         username: Optional[str] = "",
         password: Optional[str] = "",
         hostname: str = "",
         dbname: Optional[str] = "",
-        port: int = SQCLOUD_DEFAULT.PORT.value,
+        port: int = SQLITECLOUD_DEFAULT.PORT.value,
         apikey: Optional[str] = "",
     ) -> None:
         # User name is required unless connectionstring is provided
@@ -117,32 +129,33 @@ class SqliteCloudAccount:
         self.port = port
 
 
-class SQCloudConnect:
+class SQLiteCloudConnect:
     """
     Represents the connection information.
     """
 
     def __init__(self):
         self.socket: any = None
-        self.config: SQCloudConfig
+        self.config: SQLiteCloudConfig
         self.isblob: bool = False
 
         self.pubsub_socket: any = None
         self.pubsub_callback: Callable[
-            [SQCloudConnect, Optional[types.SqliteCloudResultSet], Optional[any]], None
+            [SQLiteCloudConnect, Optional[types.SqliteCloudResultSet], Optional[any]],
+            None,
         ] = None
         self.pubsub_data: any = None
         self.pubsub_thread: AbstractEventLoop = None
 
 
-class SQCloudConfig:
-    def __init__(self) -> None:
-        self.account: SqliteCloudAccount = None
+class SQLiteCloudConfig:
+    def __init__(self, connection_str: Optional[str] = None) -> None:
+        self.account: SQLiteCloudAccount = None
 
         # Optional query timeout passed directly to TLS socket
         self.timeout = 0
         # Socket connection timeout
-        self.connect_timeout = SQCLOUD_DEFAULT.TIMEOUT.value
+        self.connect_timeout = SQLITECLOUD_DEFAULT.TIMEOUT.value
 
         # Enable compression
         self.compression = False
@@ -173,15 +186,74 @@ class SQCloudConfig:
         # Server should limit total number of rows in a set to maxRowset
         self.maxrowset = 0
 
+        if connection_str is not None:
+            self._parse_connection_string(connection_str)
 
-class SQCloudException(Exception):
+    def _parse_connection_string(self, connection_string) -> None:
+        # URL STRING FORMAT
+        # sqlitecloud://user:pass@host.com:port/dbname?timeout=10&key2=value2&key3=value3
+        # or sqlitecloud://host.sqlite.cloud:8860/dbname?apikey=zIiAARzKm9XBVllbAzkB1wqrgijJ3Gx0X5z1A4m4xBA
+
+        self.account = SQLiteCloudAccount()
+
+        try:
+            params = parse.urlparse(connection_string)
+
+            options = {}
+            query = params.query
+            options = parse.parse_qs(query)
+            for option, values in options.items():
+                opt = option.lower()
+                value = values.pop()
+
+                if value.lower() in ["true", "false"]:
+                    value = bool(value)
+                elif value.isdigit():
+                    value = int(value)
+                else:
+                    value = value
+
+                # alias
+                if opt == "nonlinearizable":
+                    opt = "non_linearizable"
+
+                if hasattr(self, opt):
+                    setattr(self, opt, value)
+                elif hasattr(self.account, opt):
+                    setattr(self.account, opt, value)
+
+            # apikey or username/password is accepted
+            if not self.account.apikey:
+                self.account.username = (
+                    parse.unquote(params.username) if params.username else ""
+                )
+                self.account.password = (
+                    parse.unquote(params.password) if params.password else ""
+                )
+
+            path = params.path
+            database = path.strip("/")
+            if database:
+                self.account.dbname = database
+
+            self.account.hostname = params.hostname
+            self.account.port = (
+                int(params.port) if params.port else SQLITECLOUD_DEFAULT.PORT.value
+            )
+        except Exception as e:
+            raise SQLiteCloudException(
+                f"Invalid connection string {connection_string}"
+            ) from e
+
+
+class SQLiteCloudException(Exception):
     def __init__(self, message: str, code: int = -1, xerrcode: int = 0) -> None:
         self.errmsg = str(message)
         self.errcode = code
         self.xerrcode = xerrcode
 
 
-class SQCloudNumber:
+class SQLiteCloudNumber:
     """
     Represents the parsed number or the error code.
     """
@@ -192,7 +264,7 @@ class SQCloudNumber:
         self.extcode: int = None
 
 
-class SQCloudValue:
+class SQLiteCloudValue:
     """
     Represents the parse value.
     """
